==> field_login-2.0.1.zip: field_login/src/FieldLoginPluginManager.php <==
<?php

namespace Drupal\field_login;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;

/**
 * FieldLogin plugin manager.
 */
class FieldLoginPluginManager extends DefaultPluginManager {

  /**
   * Constructs FieldLoginPluginManager object.
   *
   * @param \Traversable $namespaces
   *   An object that implements \Traversable which contains the root paths
   *   keyed by the corresponding namespace to look for plugin implementations.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache_backend
   *   Cache backend instance to use.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler to invoke the alter hook with.
   */
  public function __construct(\Traversable $namespaces, CacheBackendInterface $cache_backend, ModuleHandlerInterface $module_handler) {
    parent::__construct(
      'Plugin/FieldLogin',
      $namespaces,
      $module_handler,
      'Drupal\field_login\FieldLoginInterface',
      'Drupal\field_login\Annotation\FieldLogin'
    );
    $this->alterInfo('field_login_info');
    $this->setCacheBackend($cache_backend, 'field_login_plugins');
  }

  /**
   * Determine if the plugin exists.
   *
   * @param string $field_name
   *   Implement the field name for user login.
   *
   * @return bool
   *    Determine if the plugin exists.
   */
  public function hasFieldLoginPlugin(string $field_name): bool {
    $fields = \Drupal::service('entity_field.manager')
      ->getFieldDefinitions('user', 'user');

    foreach ($this->getDefinitions() as $plugin_id => $plugin_info) {
      if ($plugin_info['field_name'] == $field_name &&
        $fields['phone']->getType() == $plugin_info['field_type']
      ) {
        return TRUE;
      }
    }

    return FALSE;
  }

  /**
   * Get the user's UID from the plugin.
   *
   * @param string $field_name
   *   Implement the field name for user login.
   * @param string $inputValue
   *   The value passed in by the user login form.
   *
   * @return array
   *    UID for loading user entity data.
   */
  public function getFieldLoginPlugin(string $field_name, string $inputValue): array {
    foreach ($this->getDefinitions() as $plugin_id => $plugin_info) {
      if ($this->hasFieldLoginPlugin($field_name)) {
        $instances = $this->createInstance($plugin_id);
        return $instances->getAccountUid($inputValue);
      }
    }
    return [];
  }

}

==> field_login-2.0.2.zip: field_login/src/FieldLoginPluginManager.php <==
<?php

namespace Drupal\field_login;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;

/**
 * FieldLogin plugin manager.
 */
class FieldLoginPluginManager extends DefaultPluginManager {

  /**
   * Constructs FieldLoginPluginManager object.
   *
   * @param \Traversable $namespaces
   *   An object that implements \Traversable which contains the root paths
   *   keyed by the corresponding namespace to look for plugin implementations.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache_backend
   *   Cache backend instance to use.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler to invoke the alter hook with.
   */
  public function __construct(\Traversable $namespaces, CacheBackendInterface $cache_backend, ModuleHandlerInterface $module_handler) {
    parent::__construct(
      'Plugin/FieldLogin',
      $namespaces,
      $module_handler,
      'Drupal\field_login\FieldLoginInterface',
      'Drupal\field_login\Annotation\FieldLogin'
    );
    $this->alterInfo('field_login_info');
    $this->setCacheBackend($cache_backend, 'field_login_plugins');
  }

  /**
   * Determine if the plugin exists.
   *
   * @param string $field_name
   *   Implement the field name for user login.
   *
   * @return bool
   *   Determine if the plugin exists.
   */
  public function hasFieldLoginPlugin(string $field_name): bool {
    $fields = \Drupal::service('entity_field.manager')
      ->getFieldDefinitions('user', 'user');

    foreach ($this->getDefinitions() as $plugin_id => $definition) {
      if ($definition['field_name'] == $field_name &&
        $fields[$field_name]->getType() == $definition['field_type']
      ) {
        return TRUE;
      }
    }

    return FALSE;
  }

  /**
   * Get the user's UID from the plugin.
   *
   * @param string $field_name
   *   Implement the field name for user login.
   * @param string $inputValue
   *   The value passed in by the user login form.
   *
   * @return array
   *   UID for loading user entity data.
   */
  public function getFieldLoginPlugin(string $field_name, string $inputValue): array {
    foreach ($this->getDefinitions() as $plugin_id => $definition) {
      if ($this->hasFieldLoginPlugin($field_name)) {
        $instances = $this->createInstance($plugin_id);
        return $instances->getAccountUid($inputValue);
      }
    }
    return [];
  }

}
